@@ -279,20 +279,45 @@ async def present(
                 result["new_state"] = result["old_state"]
                 return result
 
-        are_peerings_changed = (
-            not hub.tool.gcp.state_comparison_utils.are_lists_identical(
-                result["old_state"].get("peerings"), peerings
-            )
+        peerings = hub.tool.gcp.compute.network.build_new_peerings_on_top_of_old(
+            result["old_state"].get("peerings"), peerings
         )
 
-        if not changes and not are_peerings_changed:
+        # We want to make sure that the network in the current and new peerings have the same format.
+        for peering in result["old_state"].get("peerings", []):
+            peering[
+                "network"
+            ] = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
+                peering["network"], "compute.network"
+            )
+        for peering in peerings or []:
+            peering[
+                "network"
+            ] = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
+                peering["network"], "compute.network"
+            )
+
+        peerings_changes = None
+        if peerings is not None:
+            request_body["peerings"] = peerings
+            peerings_changes = hub.tool.gcp.utils.compare_states(
+                {"peerings": result["old_state"].get("peerings") or []},
+                {"peerings": peerings},
+                resource_type=None,
+                additional_exclude_paths=[
+                    "peerings[].peer_mtu",
+                    "peerings[].auto_create_routes",
+                ],
+            )
+
+        if not changes and not peerings_changes:
             result["result"] = True
             result["comment"].append(
                 hub.tool.gcp.comment_utils.up_to_date_comment(
                     "gcp.compute.network", name
                 )
             )
-            result["new_state"] = {"resource_id": resource_id, **request_body}
+            result["new_state"] = result["old_state"]
             return result
 
         if ctx["test"]:
@@ -304,17 +329,17 @@ async def present(
             result["new_state"] = {"resource_id": resource_id, **request_body}
             return result
 
-        if are_peerings_changed:
+        if peerings_changes:
             update_peerings_ret = await hub.tool.gcp.compute.network.update_peerings(
                 ctx, resource_id, result["old_state"].get("peerings"), peerings
             )
             if not update_peerings_ret["result"]:
                 result["result"] = False
-                result["comment"].append(update_peerings_ret["comment"])
+                result["comment"] += update_peerings_ret["comment"]
                 return result
 
         if changes:
-            if are_peerings_changed:
+            if peerings_changes:
                 get_ret = await hub.exec.gcp.compute.network.get(
                     ctx, resource_id=resource_id
                 )
@@ -323,7 +348,7 @@ async def present(
                     result["comment"] += get_ret["comment"]
                     return result
 
-                # The network interfaces should be the same so update does not happen there
+                # The peerings should be the same so update does not happen there
                 request_body["peerings"] = get_ret["ret"].get("peerings")
 
             patch_ret = await hub.exec.gcp_api.client.compute.network.patch(
