@@ -5,6 +5,10 @@ from typing import Any
 from typing import Dict
 from typing import List
 
+from idem_gcp.tool.gcp.utils import zonal_absent
+
+# prevent commit hook from removing the import
+absent = zonal_absent
 
 __contracts__ = ["resource"]
 
@@ -121,43 +125,6 @@ async def present(
     return result
 
 
-async def absent(
-    hub,
-    ctx,
-    name: str = None,
-    project: str = None,
-    zone: str = None,
-    resource_id: str = None,
-) -> Dict[str, Any]:
-    r"""Deletes the resource.
-
-    Args:
-        name(str, Optional):
-            An Idem name of the resource.
-
-        project(str, Optional):
-            Project ID for this request.
-
-        zone(str, Optional):
-            Name of the zone for this request.
-
-        resource_id(str, Optional):
-            An identifier of the resource in the provider. Defaults to None.
-
-    Returns:
-        Dict[str, Any]
-
-    Examples:
-        .. code-block:: sls
-
-            my-reservation:
-              gcp.compute.reservation.absent:
-                - resource_id: projects/project-name/zones/us-central1-a/reservations/my-reservation
-    """
-    # the method is handled via the recursive_contracts->call_absent
-    raise NotImplementedError
-
-
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
     r"""Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
