@@ -31,10 +31,11 @@ class StateOperations:
         }
         self.changed_properties_dict = {
             k: {}
-            if not resource_body.get(k)
+            if resource_body.get(k) is None
             else hub.tool.gcp.utils.compare_states(
                 {k: self.old_properties_dict.get(k)},
                 {k: resource_body.get(k)},
+                resource_type,
             )
             for k in patch_operations_dict.keys()
         }
