@@ -212,6 +212,14 @@ def compare_states(
         else []
     )
 
+    if (old_state is None or plan_state is None) and old_state != plan_state:
+        return DeepDiff(
+            old_state,
+            plan_state,
+            exclude_regex_paths=exclude_paths,
+            ignore_type_in_groups=[(NamespaceDict, dict)],
+        )
+
     for key in old_state.keys():
         if key not in plan_state:
             exclude_paths.append(f"root['{key}']")
@@ -308,7 +316,7 @@ def filter_diff(hub, changes, plan_state):
         changes["dictionary_item_added"] = filtered_added_items
 
 
-def get_project_from_account(hub, ctx: dict, project: str) -> str:
+def get_project_from_account(hub, ctx: dict, project: str = None) -> str:
     """If project is explicitly passed by the user, this project will be returned.
     If project is empty, this method will return gcp account default project
     :param ctx: A dict with the keys/values for the execution of the Idem run
@@ -325,7 +333,7 @@ def get_project_from_account(hub, ctx: dict, project: str) -> str:
 
 # TODO: Enhance this method to work for multi dictionary layers as opposed to now working with only the top one.
 def create_dict_body_on_top_of_old(
-    hub, ctx, old: Dict[str, Any], new: Dict[str, Any]
+    hub, old: Dict[str, Any], new: Dict[str, Any]
 ) -> Dict[str, Any]:
     result = copy.copy(old)
     for key, value in new.items():
